# -*- coding: utf-8 -*-
"""
Created on Sat Mar 30 19:16:28 2019

@author: nicon
"""
import visa
import numpy as np
import time


class GeneradorFuncionesRigol(object):

    def __init__(self, instrument_addres='TCPIP0::10.99.45.51::INSTR'):
        self.rm = visa.ResourceManager()

        try:
            self.inst = self.rm.open_resource(instrument_addres)
        except:
            raise 'no rigo gen in lan detected'
        if self.inst != []:
            try:
                print('El IDN del instrumento es ', self.inst.query("*IDN?"))
            except:
                print('El instrumento no respondió cuando se le preguntó el nombre.')
    
    def TurnOn(self, channel = 1): 
        self.inst.write("OUTPut{}:STATe ON".format(channel))
        
    def TurnOff(self, channel = 1): 
        self.inst.write("OUTPut{}:STATe OFF".format(channel))
        
    def State(self, channel = 1): 
        print(self.inst.query('OUTP{}:STAT?'.format(channel)))
    
    @property
    def Frequency(self, channel = 1):
        """
        The frequency you set is in Hz
        """
        return self.inst.query(':SOUR{}:APPL?'.format(channel)).split(",")[1]
    
    @Frequency.setter    
    def Frequency(self, freq, channel = 1):
        self.inst.write("SOURce{}:FREQuency {}".format(channel,freq))
    
    @property
    def Shape(self, channel = 1):
        """
        SINusoid|SQUare|RAMP|PULSe|NOISe|USER|DC|SINC|EXPRise|EXPFall|CARDiac|GAUSsian
        |HAVersine|LORentz|ARBPULSE|DUAltone
    
        """
        print(self.inst.query(':SOUR{}:APPL?'.format(channel)).split(",")[0])
    
    @Shape.setter
    def Shape(self, shape, channel = 1):

        self.inst.write('SOURce{}:FUNCtion {}'.format(channel, shape))
        
    @property
    def Voltage(self, channel = 1):
        """
        The voltage you set is in Vpp
        """
        return self.inst.query(':SOUR{}:APPL?'.format(channel)).split(",")[2]
    
    @Voltage.setter
    def Voltage(self, voltage, channel = 1):
        self.inst.write('SOURce{}:VOLTage:LEVel:IMMediate:AMPLitude {}'.format(channel, voltage))
    
    @property
    def Offset(self, channel = 1):
        """
        The offset you set is in Vpp
        """
        return self.inst.query(':SOUR{}:APPL?'.format(channel)).split(",")[3]
    
    @Offset.setter
    def Offset(self, offset, channel = 1):
        self.inst.write('SOURce{}:VOLTage:LEVel:IMMediate:OFFSet {}'.format(channel, offset))        
    
    def GeneralSet(self, freq, voltage, offset = '0 V', shape = 'SIN', channel = 1):
        self.SetFrequency(freq, channel)
        self.SetVoltage(voltage, channel)
        self.SetOffset(offset, channel)
    
    def DiscreteSweep(self, freqini, freqfin, step, timeoff = 1,  channel = 1):
        Frequencies = np.arange(freqini, freqfin + step, step)
        for Fr in Frequencies:
            self.inst.write("SOURce{}:FREQuency {}".format(channel, Fr))
            time.sleep(timeoff)
        
    def __del__(self):
        self.TurnOff()
        self.rm.close()