    
from appsettings import CAMERA_TYPE, RIGOL_GEN
if CAMERA_TYPE['dummy']==True:
    from drivers.dummyAndor import AndorZyla
else:
    from drivers.andorzyla import AndorZyla

from drivers.GeneradorFuncionesRigol import GeneradorFuncionesRigol
from rigolGui import RigolGenGui

from cameraGui import CameraGuiMainWindow
from zylaCameraWorker import CameraWorker
from MCDAQcontrolsignals import anal_control_signal
from MCDAQcontrolsignals import digital_control_signal
from controlGui import ControlGui

from PyQt5 import QtGui, QtCore

import logging
from logging.handlers import SocketHandler


if __name__ == "__main__":
    log = logging.getLogger('Main logger')
    gui_log = log.getChild("GUI logger")
    worker_log = log.getChild("Worker logger")
    acq_log = log.getChild("Acquisition logger")


    log.setLevel(1)  # to send all records to cutelog
    socket_handler = SocketHandler('127.0.0.1', 19996)  # default listening address
    log.addHandler(socket_handler)
    log.info('Hello world!')
    gui_log.info('hello')
    worker_log.info('hello')
    acq_log.info('hello')

    import sys
    app = QtGui.QApplication([])
    app_icon = QtGui.QIcon()
    app_icon.addFile('Butter_robot.png')
    app.setWindowIcon(app_icon)
    
    camera = AndorZyla(0)
    if RIGOL_GEN:
        rigGen = GeneradorFuncionesRigol()
        rigGenGui = RigolGenGui(rigGen)

    
    piezoA397 = anal_control_signal('piezoA397', channel=13, ao_type='cavity_piezo', out_minimum = 0, out_maximum = 4)
    piezoB397 = anal_control_signal('piezoB397', channel=7, ao_type='cavity_piezo')
    piezoA866 = anal_control_signal('piezoA866', channel=14, ao_type='cavity_piezo', out_minimum = 0, out_maximum = 4)
    piezoB866 = anal_control_signal('piezoB866', channel=9, ao_type='cavity_piezo', out_minimum = -2, out_maximum = 10)
    piezo423 = anal_control_signal('piezo423', channel=3, ao_type='laser_piezo')
    
    trapDCA = anal_control_signal('dcA', channel = 2, ao_type='electrode')
    trapDCB = anal_control_signal('dcB', channel = 1, ao_type='electrode')
    trapCOMPC = anal_control_signal('compC', channel = 4, ao_type='electrode')
    trapCOMPD = anal_control_signal('compD', channel = 5, ao_type='electrode')
    trapOven = anal_control_signal('compOven', channel = 0, ao_type='electrode')
    trapExYb = anal_control_signal('compExYb', channel = 6, ao_type='electrode')


    shutter866 = digital_control_signal('shutter866', channel = 2, inverse=False)
    shutter397 = digital_control_signal('shutter397', channel = 0, inverse=False)
    shutter423 = digital_control_signal('shutter423', channel = 1, inverse=False)
    shutter866WM = digital_control_signal('shutter866WM', channel = 3, inverse=False)

    controlGui = ControlGui()
    backendThread = QtCore.QThread()

    for ao in anal_control_signal._registry:
        controlGui.make_connections(ao)
        ao.make_connections(controlGui)
        ao.moveToThread(backendThread)
        ao.scanTimer.moveToThread(backendThread)
        ao.scanTimer.timeout.connect(ao.scan_event)
    for do in digital_control_signal._registry:
        do.make_connections(controlGui)
        do.moveToThread(backendThread)


    cameraMainWindow = CameraGuiMainWindow()
    if RIGOL_GEN:
       cameraWorker = CameraWorker(camera, rigGen)
    else:
        cameraWorker = CameraWorker(camera)


    cameraWorker.moveToThread(backendThread)

    cameraWorker.make_connections(cameraMainWindow)
    cameraMainWindow.make_connections(cameraWorker)

    backendThread.start()

    controlGui.toolbar.load()
    
    app.exec_()
    if RIGOL_GEN:
        rigGen.__del__()
    try:
        camera.shutdown()
    except:
        print('Proper shutdown of camera failed')