#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
tip: pyuic5 -x ventana.ui -o ventana_ui.py
@author: martindrech

Control of rigol function generator
"""

from resources.rigol_gen_ui import Ui_Frame
from PyQt5 import QtCore, QtWidgets, QtGui


class RigolGenGui(QtWidgets.QFrame, Ui_Frame):
    registry = []

    def __init__(self, rigGen):
        super().__init__()
        self.setupUi(self)
        self.registry.append(self)
        
        self.rigGen = rigGen

        self.sb_amp.setRange(0, 20)
        self.sb_amp.setSuffix('V')
        self.sb_amp.setSingleStep(.2)
        self.sb_amp.setOpts(siPrefix=True)


        self.sb_freq.setRange(0, 10000000)
        self.sb_freq.setSingleStep(200)
        self.sb_freq.setOpts(siPrefix=True)
        self.sb_freq.setSuffix('Hz')

        self.sb_offset.setRange(-7.5, 7.5)
        self.sb_offset.setSuffix('V')
        self.sb_offset.setSingleStep(.2)
        self.sb_offset.setOpts(siPrefix=True)

        self.make_connections()

        self.sb_amp.setValue(1)
        self.rigGen.Voltage = 1
        self.sb_freq.setValue(50)
        self.rigGen.Frequency = 50
        self.sb_offset.setValue(0)
        self.rigGen.Offset = 0

        self.show()

    def make_connections(self):
        self.cb_onOff.stateChanged.connect(self.turn_on_off)
        self.sb_amp.sigValueChanging.connect(self.set_amp)
        self.sb_freq.sigValueChanging.connect(self.set_freq)
        self.sb_offset.sigValueChanging.connect(self.set_offset)


    @QtCore.pyqtSlot(object)
    def set_freq(self, sb):
        self.rigGen.Frequency = sb.value()

    @QtCore.pyqtSlot(object)
    def set_amp(self, sb):
        self.rigGen.Voltage = sb.value()

    @QtCore.pyqtSlot(object)
    def set_offset(self, sb):
        self.rigGen.Offset = sb.value()

    @QtCore.pyqtSlot()
    def turn_on_off(self):
        if self.cb_onOff.isChecked():
            self.rigGen.TurnOn()
        else:
            self.rigGen.TurnOff()

    def __del__(self):
        self.rigGen.__del__()